@@ -345,25 +345,12 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 
 		// group params
 		$gparams = new JRegistry($group->get('params'));
+		$gparams->merge(new JRegistry($g['params']));
 
 		// set membership control param
 		$membership_control = (isset($g['params']['membership_control'])) ? 1 : 0;
 		$gparams->set('membership_control', $membership_control);
-
-		// make array of params
-		$gparams = $gparams->toArray();
-
-		// array to hold params
-		$params = array();
-
-		// create key=val from each param
-		foreach ($gparams as $key => $val)
-		{
-			$params[] = $key . '=' . $val;
-		}
-
-		//each param must have its own line
-		$params = implode("\n", $params);
+		$params = $gparams->toString();
 
 		// Set the group changes and save
 		$group->set('cn', $g['cn']);
@@ -388,6 +375,7 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 		$group->set('restrict_msg', $g['restrict_msg']);
 		$group->set('logo', $g['logo']);
 		$group->set('plugins', $g['plugins']);
+		$group->set('discussion_email_autosubscribe', $g['discussion_email_autosubscribe']);
 		$group->set('params', $params);
 		$group->update();
 
@@ -454,12 +442,12 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 		// copy over default template recursively
 		// must have  /. at the end of source path to get all items in that directory
 		// also doesnt overwrite already existing files/folders
-		shell_exec("cp -rn $srcPath $uploadPath");
+		shell_exec("cp -rn $srcPath $uploadPath 2>&1");
 
 		// make sure files are group read and writable
 		// make sure files are all group owned properly
-		shell_exec("chmod -R 2770 $uploadPath");
-		shell_exec("chgrp -R " . $this->config->get('super_group_file_owner', 'access-content') . " " . $uploadPath);
+		shell_exec("chmod -R 2770 $uploadPath 2>&1");
+		shell_exec("chgrp -R " . escapeshellcmd($this->config->get('super_group_file_owner', 'access-content')) . " " . $uploadPath . " 2>&1");
 
 		// get all current users granted permissionss
 		$this->database->setQuery("SHOW GRANTS FOR CURRENT_USER();");
@@ -656,10 +644,11 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 	}
 
 	/**
-	 * Pull from Gitlab
+	 * Fetch from Gitlab
+	 * 
 	 * @return void
 	 */
-	public function pullTask()
+	public function updateTask()
 	{
 		// Check for request forgeries
 		JRequest::checkToken() or jexit('Invalid Token');
@@ -673,6 +662,13 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 			$ids = array($ids);
 		}
 
+		// empty list?
+		if (empty($ids))
+		{
+			$this->setRedirect('index.php?option=' . $this->_option . '&controller=' . $this->_controller);
+			return;
+		}
+
 		// vars to hold results of pull
 		$success = array();
 		$failed  = array();
@@ -702,8 +698,11 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 			// make sure we have an upload path
 			if (!is_dir($uploadPath))
 			{
-				$failed[] = array('group' => $group->get('cn'), 'message' => JText::_('COM_GROUPS_GITLAB_UPLOAD_PATH_DOESNT_EXIST'));
-				continue;
+				if (!JFolder::create($uploadPath))
+				{
+					$failed[] = array('group' => $group->get('cn'), 'message' => JText::_('COM_GROUPS_GITLAB_UPLOAD_PATH_DOESNT_EXIST'));
+					continue;
+				}
 			}
 
 			// make sure we have a git repo
@@ -719,7 +718,8 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 
 				// build group & project names
 				$host        = explode('.', $_SERVER['HTTP_HOST']);
-				$groupName   = strtolower($host[0]);
+				$tld         = array_pop($host);
+				$groupName   = strtolower(end($host));
 				$projectName = $group->get('cn');
 
 				// get gitlab config
@@ -740,22 +740,116 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 
 				// setup stage environment
 				$cmd  = 'sh ' . JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_groups' . DS . 'assets' . DS . 'scripts' . DS . 'gitlab_setup_stage.sh ';
-				$cmd .= str_replace('/' . $group->get('gidNumber'), '', $uploadPath) . ' ' . $group->get('gidNumber') . ' ' . $gitlabProject['ssh_url_to_repo'] . ' 2>&1';
+				$cmd .= str_replace('/' . $group->get('gidNumber'), '', $uploadPath) . ' ' . $group->get('gidNumber') . ' ' . $group->get('cn') . ' ' . $gitlabProject['ssh_url_to_repo'] . ' 2>&1';
 
 				// execute command
 				$output = shell_exec($cmd);
 			}
 
+			// build command to run via shell
+			$cmd  = 'sh ' . JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_groups' . DS . 'assets' . DS . 'scripts' . DS . 'gitlab_fetch.sh ';
+			$cmd .= $uploadPath . ' ' . JPATH_ROOT . ' 2>&1';
+
+			// execute command
+			$output = shell_exec($cmd);
+			$output = json_decode($output);
+
+			// did we succeed
+			if ($output == '' || json_last_error() == JSON_ERROR_NONE)
+			{
+				// code is up to date
+				$output = ($output == '') ? array(JText::_('COM_GROUPS_FETCH_CODE_UP_TO_DATE')) : $output;
+
+				// add success message
+				$success[] = array('group' => $group->get('cn'), 'message' => $output);
+			}
+			else
+			{
+				// add failed message
+				$failed[] = array('group' => $group->get('cn'), 'message' => $output);
+			}
+		}
+
+		// display view
+		$this->view->setLayout('fetched');
+		$this->view->success = $success;
+		$this->view->failed  = $failed;
+		$this->view->config  = $this->config;
+		$this->view->display();
+	}
+
+	/**
+	 * Merge From from Gitlab
+	 * 
+	 * @return void
+	 */
+	public function doUpdateTask()
+	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
+		// Incoming
+		$ids = JRequest::getVar('id', array());
+
+		// Get the single ID we're working with
+		if (!is_array($ids))
+		{
+			$ids = array($ids);
+		}
+
+		// empty list?
+		if (empty($ids))
+		{
+			$this->setRedirect('index.php?option=' . $this->_option . '&controller=' . $this->_controller);
+			return;
+		}
+
+		// vars to hold results of pull
+		$success = array();
+		$failed  = array();
+
+		// loop through each group and pull code from repos
+		foreach ($ids as $id)
+		{
+			// Load the group page
+			$group = \Hubzero\User\Group::getInstance($id);
+
+			// Ensure we found the group info
+			if (!$group)
+			{
+				continue;
+			}
+
+			// make sure its a super group
+			if (!$group->isSuperGroup())
+			{
+				$failed[] = array('group' => $group->get('cn'), 'message' => JText::_('COM_GROUPS_GITLAB_NOT_SUPER_GROUP'));
+				continue;
+			}
+
+			// path to group folder
+			$uploadPath = JPATH_ROOT . DS . trim($this->config->get('uploadpath', '/site/groups'), DS) . DS . $group->get('gidNumber');
+
+			// make sure we have an upload path
+			if (!is_dir($uploadPath))
+			{
+				if (!JFolder::create($uploadPath))
+				{
+					$failed[] = array('group' => $group->get('cn'), 'message' => JText::_('COM_GROUPS_GITLAB_UPLOAD_PATH_DOESNT_EXIST'));
+					continue;
+				}
+			}
+
 			// build command to run via shell
 			// this will run a "git pull --rebase origin master"
-			$cmd  = 'sh ' . JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_groups' . DS . 'assets' . DS . 'scripts' . DS . 'gitlab_pull_and_migrate.sh ';
+			$cmd  = 'sh ' . JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_groups' . DS . 'assets' . DS . 'scripts' . DS . 'gitlab_merge_and_migrate.sh ';
 			$cmd .= $uploadPath . ' ' . JPATH_ROOT . ' 2>&1';
 
 			// execute command
 			$output = shell_exec($cmd);
 
 			// did we succeed
-			if (preg_match("/Updating the repository...complete/uis", $output))
+			if (preg_match("/Updating the repository.../uis", $output))
 			{
 				// add success message
 				$success[] = array('group' => $group->get('cn'), 'message' => $output);
@@ -768,7 +862,7 @@ class GroupsControllerManage extends \Hubzero\Component\AdminController
 		}
 
 		// display view
-		$this->view->setLayout('pull');
+		$this->view->setLayout('merged');
 		$this->view->success = $success;
 		$this->view->failed  = $failed;
 		$this->view->config  = $this->config;
