@@ -107,7 +107,7 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 
 	<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
 	<input type="hidden" name="controller" value="<?php echo $this->controller; ?>" />
-	<input type="hidden" name="task" value="" />
+	<input type="hidden" name="task" value="displayClasses" />
 	<input type="hidden" name="boxchecked" value="0" />
 	<?php echo JHTML::_('form.token'); ?>
 </form>
\ No newline at end of file
