@@ -68,16 +68,20 @@ class OaipmhControllerConfig extends \Hubzero\Component\AdminController
 		JRequest::checkToken() or jexit('Invalid Token');
 
 		// vars
-		$queries = JRequest::getVar('queries','','post');
-		$qid     = JRequest::getVar('qid','','post');
-		$display = JRequest::getVar('display','','post');
+		$queries = JRequest::getVar('queries', array(), 'post');
+		$qid     = JRequest::getVar('qid', '', 'post');
+		$display = JRequest::getVar('display', '', 'post');
 
 		// update specs
 		$count = count($queries);
 		for ($i=0; $i<=$count-1; $i++)
 		{
 			$SQL = "UPDATE `#__oaipmh_dcspecs` SET query = " . $this->database->Quote($queries[$i]) . " WHERE id = " . $this->database->Quote($qid[$i]);
-			$this->database->Execute($SQL);
+			$this->database->setQuery($SQL);
+			if (!$this->database->query())
+			{
+				$this->setError($this->database->getErrorMsg());
+			}
 		}
 
 		// redirect
@@ -92,10 +96,10 @@ class OaipmhControllerConfig extends \Hubzero\Component\AdminController
 	 * 
 	 * @return     void
 	 */
-	protected function addsetTask()
+	public function addsetTask()
 	{
 		// increment set number, load a fresh one
-		$sets = JRequest::getVar('sets', '', 'request');
+		$sets = JRequest::getInt('sets', 1);
 
 		$names = array(
 			'resource IDs',
@@ -116,11 +120,21 @@ class OaipmhControllerConfig extends \Hubzero\Component\AdminController
 			'language',
 			'source'
 		);
-		for ($i=0; $i<17; $i++)
+		foreach ($names as $name)
 		{
-			$SQL = "INSERT INTO `#__oaipmh_dcspecs` (name, query, display) VALUES (" . $this->database->Quote($names[$i]) . ",''," . $this->database->Quote($sets) . ")";
-			$this->database->Execute($SQL);
+			$SQL = "INSERT INTO `#__oaipmh_dcspecs` (name, query, display) VALUES (" . $this->database->Quote($name) . ",''," . $this->database->Quote($sets) . ")";
+			$this->database->setQuery($SQL);
+			if (!$this->database->query())
+			{
+				$this->setError($this->database->getErrorMsg());
+			}
 		}
+
+		if ($this->getError())
+		{
+			echo $this->getError();
+		}
+
 		// redirect
 		$this->setRedirect(
 			'index.php?option=' . $this->_option,
@@ -139,7 +153,11 @@ class OaipmhControllerConfig extends \Hubzero\Component\AdminController
 		$id = JRequest::getVar('id', '', 'request');
 
 		$SQL = "DELETE FROM `#__oaipmh_dcspecs` WHERE display = " . $this->database->Quote($id) . " LIMIT 17";
-		$this->database->Execute($SQL);
+		$this->database->setQuery($SQL);
+		if (!$this->database->query())
+		{
+			$this->setError($this->database->getErrorMsg());
+		}
 
 		// redirect
 		$this->setRedirect(
