@@ -406,8 +406,8 @@ class SupportControllerTickets extends \Hubzero\Component\AdminController
 		}
 
 		// Save the tags
-		$row->set('tags', JRequest::getVar('tags', '', 'post'));
-		$row->tag($row->get('tags'), $this->juser->get('id'), 1);
+		$row->tag(JRequest::getVar('tags', '', 'post'), $this->juser->get('id'), 1);
+		$row->set('tags', $row->tags('string'));
 
 		$juri = JURI::getInstance();
 		$jconfig = JFactory::getConfig();
@@ -420,7 +420,11 @@ class SupportControllerTickets extends \Hubzero\Component\AdminController
 
 		$webpath = trim($this->config->get('webpath'), '/');
 
-		$allowEmailResponses = $this->config->get('email_processing');
+		$allowEmailResponses = false;
+		if ($this->config->get('email_processing') and file_exists("/etc/hubmail_gw.conf"))
+		{
+			$allowEmailResponses = true;
+		}
 		if ($allowEmailResponses)
 		{
 			$encryptor = new \Hubzero\Mail\Token();
@@ -588,13 +592,16 @@ class SupportControllerTickets extends \Hubzero\Component\AdminController
 
 			// Message people watching this ticket, 
 			// but ONLY if the comment was NOT marked private
-			if (!$rowc->isPrivate())
+			$this->acl = SupportACL::getACL();
+			foreach ($row->watchers() as $watcher)
 			{
-				foreach ($row->watchers() as $watcher)
+				$this->acl->setUser($watcher->user_id);
+				if (!$rowc->isPrivate() || ($rowc->isPrivate() && $this->acl->check('read', 'private_comments')))
 				{
 					$rowc->addTo($watcher->user_id, 'watcher');
 				}
 			}
+			$this->acl->setUser($this->juser->get('id'));
 
 			if (count($rowc->to()))
 			{
@@ -654,6 +661,12 @@ class SupportControllerTickets extends \Hubzero\Component\AdminController
 					{
 						$this->setError(JText::sprintf('COM_SUPPORT_ERROR_FAILED_TO_MESSAGE', $to['name'] . '(' . $to['role'] . ')'));
 					}
+
+					// Watching should be anonymous
+					if ($to['role'] == 'watcher')
+					{
+						continue;
+					}
 					$rowc->changelog()->notified(
 						$to['role'],
 						$to['name'],
@@ -663,15 +676,15 @@ class SupportControllerTickets extends \Hubzero\Component\AdminController
 
 				foreach ($rowc->to('emails') as $to)
 				{
-					$token = $encryptor->buildEmailToken(1, 1, -9999, $id);
-
-					$email = array(
-						$to['email'],
-						'htc-' . $token . strstr($jconfig->getValue('config.mailfrom'), '@')
-					);
-
 					if ($allowEmailResponses)
 					{
+						$token = $encryptor->buildEmailToken(1, 1, -9999, $id);
+
+						$email = array(
+							$to['email'],
+							'htc-' . $token . strstr($jconfig->getValue('config.mailfrom'), '@')
+						);
+
 						// In this case each item in email in an array, 1- To, 2:reply to address
 						SupportUtilities::sendEmail($email[0], $subject, $message, $from, $email[1]);
 					}
@@ -681,6 +694,11 @@ class SupportControllerTickets extends \Hubzero\Component\AdminController
 						SupportUtilities::sendEmail($to['email'], $subject, $message, $from);
 					}
 
+					// Watching should be anonymous
+					if ($to['role'] == 'watcher')
+					{
+						continue;
+					}
 					$rowc->changelog()->notified(
 						$to['role'],
 						$to['name'],
@@ -843,6 +861,7 @@ class SupportControllerTickets extends \Hubzero\Component\AdminController
 			{
 				$users[] = JHTML::_('select.optgroup', JText::_('COM_SUPPORT_GROUP') . ' ' . $nme);
 				$users = array_merge($users, $gusers);
+				$users[] = JHTML::_('select.optgroup', JText::_('COM_SUPPORT_GROUP') . ' ' . $nme);
 			}
 		}
 
