@@ -233,13 +233,14 @@ class CitationsControllerCitations extends \Hubzero\Component\SiteController
 		}
 
 		// clean up filters a little
-		array_walk($this->view->filters, function($val, $key)
+		array_walk($this->view->filters, function(&$val, &$key)
 		{
 			if (!is_array($val))
 			{
 				$val = trim($val);
 				$val = str_replace('"', '', $val);
-				$this->view->filters[$key] = $val;
+				//$this->view->filters[$key] = $val;
+				$key = $val;
 			}
 		});
 
