@@ -31,9 +31,7 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-$base = 'index.php?option=' . $this->option . '&controller=form&gid=' . $this->course->get('alias') . '&offering=' . $this->course->offering()->get('alias') . ($this->course->offering()->section()->get('alias') != '__default' ? ':' . $this->course->offering()->section()->get('alias') : '');
-
-$route = $base . '&task=form.complete&crumb=' . $this->model->get('url');
+$route = $this->course->offering()->link() . '&task=form.complete&crumb=' . $this->model->get('url');
 
 JFactory::getApplication()->redirect(JRoute::_($route, false, false));
 
