@@ -844,6 +844,9 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 	 */
 	public function saveTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		$live_site = rtrim(JURI::base(), '/');
 
 		// Get plugins
@@ -859,7 +862,7 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 		if (!isset($_POST['reporter']) || !isset($_POST['problem']))
 		{
 			// This really, REALLY shouldn't happen.
-			JError::raiseError(500, JText::_('COM_SUPPORT_ERROR_MISSING_DATA'));
+			JError::raiseError(400, JText::_('COM_SUPPORT_ERROR_MISSING_DATA'));
 			return;
 		}
 		$reporter = JRequest::getVar('reporter', array(), 'post', 'none', 2);
@@ -1037,6 +1040,7 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 
 		// Initiate class and bind data to database fields
 		$row = new SupportModelTicket();
+		$row->set('open', 1);
 		$row->set('status', 0);
 		$row->set('created', JFactory::getDate()->toSql());
 		$row->set('login', $reporter['login']);
@@ -1151,6 +1155,7 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 			// Only do the following if a comment was posted
 			// otherwise, we're only recording a changelog
 			$old = new SupportModelTicket();
+			$old->set('open', 1);
 			$old->set('tags', '');
 
 			$rowc = new SupportModelComment();
@@ -1191,12 +1196,15 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 			// Check if the notify list has eny entries
 			if (count($rowc->to()))
 			{
-				$encryptor = new \Hubzero\Mail\Token();
-
-				$allowEmailResponses = false;
-				if ($this->config->get('email_processing') and file_exists("/etc/hubmail_gw.conf"))
+				$allowEmailResponses = $this->config->get('email_processing');
+				if (!file_exists("/etc/hubmail_gw.conf"))
 				{
-					$allowEmailResponses = true;
+					$allowEmailResponses = false;
+				}
+
+				if ($allowEmailResponses)
+				{
+					$encryptor = new \Hubzero\Mail\Token();
 				}
 
 				$subject = JText::sprintf('COM_SUPPORT_EMAIL_SUBJECT_TICKET_COMMENT', $row->get('id'));
@@ -1256,15 +1264,15 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 
 				foreach ($rowc->to('emails') as $to)
 				{
-					$token = $encryptor->buildEmailToken(1, 1, -9999, $row->get('id'));
-
-					$emails[] = array(
-						$to['email'],
-						'htc-' . $token . strstr($jconfig->getValue('config.mailfrom'), '@')
-					);
-
 					if ($allowEmailResponses)
 					{
+						$token = $encryptor->buildEmailToken(1, 1, -9999, $row->get('id'));
+
+						$email = array(
+							$to['email'],
+							'htc-' . $token . strstr($jconfig->getValue('config.mailfrom'), '@')
+						);
+
 						// In this case each item in email in an array, 1- To, 2:reply to address
 						SupportUtilities::sendEmail($email[0], $subject, $message, $from, $email[1]);
 					}
@@ -1574,6 +1582,9 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 	 */
 	public function updateTask()
 	{
+		// Check for request forgeries
+		JRequest::checkToken() or jexit('Invalid Token');
+
 		// Make sure we are still logged in
 		if ($this->juser->get('guest'))
 		{
@@ -1646,8 +1657,8 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 		}
 
 		// Save the tags
-		$row->set('tags', JRequest::getVar('tags', '', 'post'));
-		$row->tag($row->get('tags'), $this->juser->get('id'), 1);
+		$row->tag(JRequest::getVar('tags', '', 'post'), $this->juser->get('id'), 1);
+		$row->set('tags', $row->tags('string'));
 
 		// Create a new support comment object and populate it
 		$access = JRequest::getInt('access', 0);
@@ -1725,13 +1736,15 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 
 			// Message people watching this ticket, 
 			// but ONLY if the comment was NOT marked private
-			if (!$rowc->isPrivate())
+			foreach ($row->watchers() as $watcher)
 			{
-				foreach ($row->watchers() as $watcher)
+				$this->acl->setUser($watcher->user_id);
+				if (!$rowc->isPrivate() || ($rowc->isPrivate() && $this->acl->check('read', 'private_comments')))
 				{
 					$rowc->addTo($watcher->user_id, 'watcher');
 				}
 			}
+			$this->acl->setUser($this->juser->get('id'));
 
 			if (count($rowc->to()))
 			{
@@ -1803,6 +1816,12 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 					{
 						$this->setError(JText::sprintf('COM_SUPPORT_ERROR_FAILED_TO_MESSAGE', $to['name'] . '(' . $to['role'] . ')'));
 					}
+
+					// Watching should be anonymous
+					if ($to['role'] == 'watcher')
+					{
+						continue;
+					}
 					$rowc->changelog()->notified(
 						$to['role'],
 						$to['name'],
@@ -1812,15 +1831,15 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 
 				foreach ($rowc->to('emails') as $to)
 				{
-					$token = $encryptor->buildEmailToken(1, 1, -9999, $id);
-
-					$email = array(
-						$to['email'],
-						'htc-' . $token . strstr($jconfig->getValue('config.mailfrom'), '@')
-					);
-
 					if ($allowEmailResponses)
 					{
+						$token = $encryptor->buildEmailToken(1, 1, -9999, $id);
+
+						$email = array(
+							$to['email'],
+							'htc-' . $token . strstr($jconfig->getValue('config.mailfrom'), '@')
+						);
+
 						// In this case each item in email in an array, 1- To, 2:reply to address
 						SupportUtilities::sendEmail($email[0], $subject, $message, $from, $email[1]);
 					}
@@ -1830,6 +1849,11 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 						SupportUtilities::sendEmail($to['email'], $subject, $message, $from);
 					}
 
+					// Watching should be anonymous
+					if ($to['role'] == 'watcher')
+					{
+						continue;
+					}
 					$rowc->changelog()->notified(
 						$to['role'],
 						$to['name'],
@@ -2516,6 +2540,7 @@ class SupportControllerTickets extends \Hubzero\Component\SiteController
 			{
 				$users[] = JHTML::_('select.optgroup', JText::_('COM_SUPPORT_CHANGELOG_FIELD_GROUP') . ': ' . $gname);
 				$users = array_merge($users, $gusers);
+				$users[] = JHTML::_('select.optgroup', JText::_('COM_SUPPORT_CHANGELOG_FIELD_GROUP') . ': ' . $gname);
 			}
 		}
 
