@@ -38,42 +38,70 @@ class TagsTableTag extends JTable
 {
 	/**
 	 * int(11)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $id          = NULL;
 
 	/**
 	 * string(100)
-	 * 
+	 *
 	 * @var string
 	 */
 	var $tag         = NULL;
 
 	/**
 	 * string(100)
-	 * 
+	 *
 	 * @var string
 	 */
 	var $raw_tag     = NULL;
 
 	/**
 	 * text
-	 * 
+	 *
 	 * @var string
 	 */
 	var $description = NULL;
 
 	/**
 	 * tinyint(3)
-	 * 
+	 *
 	 * @var integer
 	 */
 	var $admin       = NULL;
 
+	/**
+	 * datetime(0000-00-00 00:00:00)
+	 *
+	 * @var string
+	 */
+	var $created    = NULL;
+
+	/**
+	 * int(11)
+	 *
+	 * @var integer
+	 */
+	var $created_by = NULL;
+
+	/**
+	 * datetime(0000-00-00 00:00:00)
+	 *
+	 * @var string
+	 */
+	var $modified    = NULL;
+
+	/**
+	 * int(11)
+	 *
+	 * @var integer
+	 */
+	var $modified_by = NULL;
+
 	/**
 	 * Constructor
-	 * 
+	 *
 	 * @param      object &$db JDatabase
 	 * @return     void
 	 */
@@ -85,32 +113,32 @@ class TagsTableTag extends JTable
 	/**
 	 * Load a database row and populate this object with results
 	 * Uses unique tag string as identifier
-	 * 
+	 *
 	 * @param      string $oid Tag
 	 * @return     boolean True if tag found and loaded
 	 */
 	public function loadTag($oid=NULL)
 	{
-		if ($oid === NULL) 
+		if ($oid === NULL)
 		{
 			return false;
 		}
 
 		$oid = $this->normalize($oid);
 
-		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE tag=" . $this->_db->Quote($oid) . " LIMIT 1"); //raw_tag='$oid' OR 
-		if ($result = $this->_db->loadAssoc()) 
+		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE tag=" . $this->_db->Quote($oid) . " LIMIT 1"); //raw_tag='$oid' OR
+		if ($result = $this->_db->loadAssoc())
 		{
 			return $this->bind($result);
-		} 
-		else 
+		}
+		else
 		{
 			$this->_db->setQuery("SELECT t.* FROM $this->_tbl AS t JOIN #__tags_substitute AS s ON s.tag_id=t.id WHERE s.tag=" . $this->_db->Quote($oid) . " LIMIT 1");
-			if ($result = $this->_db->loadAssoc()) 
+			if ($result = $this->_db->loadAssoc())
 			{
 				return $this->bind($result);
-			} 
-			else 
+			}
+			else
 			{
 				$this->setError($this->_db->getErrorMsg());
 				return false;
@@ -120,14 +148,14 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Delete a tag and associated content
-	 * 
+	 *
 	 * @param      integer $oid Tag ID
 	 * @return     boolean True on success, false if errors
 	 */
 	public function delete($oid=null)
 	{
 		$k = $this->_tbl_key;
-		if ($oid) 
+		if ($oid)
 		{
 			$this->$k = intval($oid);
 		}
@@ -147,7 +175,7 @@ class TagsTableTag extends JTable
 
 		$query = 'DELETE FROM #__tags_object WHERE tagid = ' . $this->_db->Quote($this->$k);
 		$this->_db->setQuery($query);
-		if (!$this->_db->query()) 
+		if (!$this->_db->query())
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
@@ -155,7 +183,7 @@ class TagsTableTag extends JTable
 
 		$query = 'DELETE FROM #__tags_substitute WHERE tag_id = ' . $this->_db->Quote($this->$k);
 		$this->_db->setQuery($query);
-		if (!$this->_db->query()) 
+		if (!$this->_db->query())
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
@@ -163,7 +191,7 @@ class TagsTableTag extends JTable
 
 		$query = 'DELETE FROM #__tags_group WHERE tagid = ' . $this->_db->Quote($this->$k);
 		$this->_db->setQuery($query);
-		if (!$this->_db->query()) 
+		if (!$this->_db->query())
 		{
 			$this->setError($this->_db->getErrorMsg());
 			return false;
@@ -210,7 +238,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Check if a tag already exists
-	 * 
+	 *
 	 * @return     boolean True if tag exists, false if not
 	 */
 	public function checkExistence()
@@ -219,7 +247,7 @@ class TagsTableTag extends JTable
 		$this->_db->setQuery("SELECT id FROM $this->_tbl WHERE tag=" . $this->_db->Quote($this->tag) . " OR raw_tag=" . $this->_db->Quote($this->raw_tag) . " LIMIT 1");
 		$id = $this->_db->loadResult();
 		// We have an ID = tag exist
-		if ($id > 0) 
+		if ($id > 0)
 		{
 			return true;
 		}
@@ -229,17 +257,17 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get the number of times a tag was used
-	 * 
+	 *
 	 * @param      integer $tagid Tag ID
 	 * @return     integer
 	 */
 	public function getUsage($tagid=NULL)
 	{
-		if (!$tagid) 
+		if (!$tagid)
 		{
 			$tagid = $this->id;
 		}
-		if (!$tagid) 
+		if (!$tagid)
 		{
 			return null;
 		}
@@ -250,7 +278,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get the number of tags on an object
-	 * 
+	 *
 	 * @param      integer $tagid    Tag ID
 	 * @param      integer $objectid Object ID
 	 * @param      string  $tbl      Object type
@@ -264,13 +292,13 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Validate data
-	 * 
+	 *
 	 * @return     True if data is valid
 	 */
 	public function check()
 	{
 		$this->raw_tag = trim($this->raw_tag);
-		if (!$this->raw_tag) 
+		if (!$this->raw_tag)
 		{
 			$this->setError(JText::_('You must enter a tag.'));
 			return false;
@@ -278,13 +306,24 @@ class TagsTableTag extends JTable
 
 		$this->tag = $this->normalize($this->raw_tag);
 
+		if (!$this->id)
+		{
+			$this->created_by = JFactory::getUser()->get('id');
+			$this->created    = JFactory::getDate()->toSql();
+		}
+		else
+		{
+			$this->modified    = ($this->modified ? $this->modified : JFactory::getDate()->toSql());
+			$this->modified_by = ($this->modified_by ? $this->modified_by : JFactory::getUser()->get('id'));
+		}
+
 		return true;
 	}
 
 	/**
 	 * Normalize a raw tag
 	 * Strips all non-alphanumeric characters
-	 * 
+	 *
 	 * @param      string $tag Raw tag
 	 * @return     string
 	 */
@@ -294,51 +333,51 @@ class TagsTableTag extends JTable
 		//echo htmlspecialchars($tag, ENT_COMPAT, 'UTF-8'); die();
 		//$tag = utf8_decode($tag);
 		$transliterationTable = array(
-			'á' => 'a', 'Á' => 'A', 'à' => 'a', 'À' => 'A', 'ă' => 'a', 'Ă' => 'A', 'â' => 'a', 'Â' => 'A', 'å' => 'a', 'Å' => 'A', 'ã' => 'a', 'Ã' => 'A', 'ą' => 'a', 'Ą' => 'A', 'ā' => 'a', 'Ā' => 'A', 'ä' => 'ae', 'Ä' => 'AE', 'æ' => 'ae', 'Æ' => 'AE', 
-			'ḃ' => 'b', 'Ḃ' => 'B', 
-			'ć' => 'c', 'Ć' => 'C', 'ĉ' => 'c', 'Ĉ' => 'C', 'č' => 'c', 'Č' => 'C', 'ċ' => 'c', 'Ċ' => 'C', 'ç' => 'c', 'Ç' => 'C', 
-			'ď' => 'd', 'Ď' => 'D', 'ḋ' => 'd', 'Ḋ' => 'D', 'đ' => 'd', 'Đ' => 'D', 'ð' => 'dh', 'Ð' => 'Dh', 
-			'é' => 'e', 'É' => 'E', 'è' => 'e', 'È' => 'E', 'ĕ' => 'e', 'Ĕ' => 'E', 'ê' => 'e', 'Ê' => 'E', 'ě' => 'e', 'Ě' => 'E', 'ë' => 'e', 'Ë' => 'E', 'ė' => 'e', 'Ė' => 'E', 'ę' => 'e', 'Ę' => 'E', 'ē' => 'e', 'Ē' => 'E', 
-			'ḟ' => 'f', 'Ḟ' => 'F', 'ƒ' => 'f', 'Ƒ' => 'F', 
-			'ğ' => 'g', 'Ğ' => 'G', 'ĝ' => 'g', 'Ĝ' => 'G', 'ġ' => 'g', 'Ġ' => 'G', 'ģ' => 'g', 'Ģ' => 'G', 
-			'ĥ' => 'h', 'Ĥ' => 'H', 'ħ' => 'h', 'Ħ' => 'H', 
-			'í' => 'i', 'Í' => 'I', 'ì' => 'i', 'Ì' => 'I', 'î' => 'i', 'Î' => 'I', 'ï' => 'i', 'Ï' => 'I', 'ĩ' => 'i', 'Ĩ' => 'I', 'į' => 'i', 'Į' => 'I', 'ī' => 'i', 'Ī' => 'I', 
-			'ĵ' => 'j', 'Ĵ' => 'J', 
-			'ķ' => 'k', 'Ķ' => 'K', 
-			'ĺ' => 'l', 'Ĺ' => 'L', 'ľ' => 'l', 'Ľ' => 'L', 'ļ' => 'l', 'Ļ' => 'L', 'ł' => 'l', 'Ł' => 'L', 
-			'ṁ' => 'm', 'Ṁ' => 'M', 
-			'ń' => 'n', 'Ń' => 'N', 'ň' => 'n', 'Ň' => 'N', 'ñ' => 'n', 'Ñ' => 'N', 'ņ' => 'n', 'Ņ' => 'N', 
-			'ó' => 'o', 'Ó' => 'O', 'ò' => 'o', 'Ò' => 'O', 'ô' => 'o', 'Ô' => 'O', 'ő' => 'o', 'Ő' => 'O', 'õ' => 'o', 'Õ' => 'O', 'ø' => 'oe', 'Ø' => 'OE', 'ō' => 'o', 'Ō' => 'O', 'ơ' => 'o', 'Ơ' => 'O', 'ö' => 'oe', 'Ö' => 'OE', 
-			'ṗ' => 'p', 'Ṗ' => 'P', 
-			'ŕ' => 'r', 'Ŕ' => 'R', 'ř' => 'r', 'Ř' => 'R', 'ŗ' => 'r', 'Ŗ' => 'R', 
-			'ś' => 's', 'Ś' => 'S', 'ŝ' => 's', 'Ŝ' => 'S', 'š' => 's', 'Š' => 'S', 'ṡ' => 's', 'Ṡ' => 'S', 'ş' => 's', 'Ş' => 'S', 'ș' => 's', 'Ș' => 'S', 'ß' => 'SS', 
-			'ť' => 't', 'Ť' => 'T', 'ṫ' => 't', 'Ṫ' => 'T', 'ţ' => 't', 'Ţ' => 'T', 'ț' => 't', 'Ț' => 'T', 'ŧ' => 't', 'Ŧ' => 'T', 
-			'ú' => 'u', 'Ú' => 'U', 'ù' => 'u', 'Ù' => 'U', 'ŭ' => 'u', 'Ŭ' => 'U', 'û' => 'u', 'Û' => 'U', 'ů' => 'u', 'Ů' => 'U', 'ű' => 'u', 'Ű' => 'U', 'ũ' => 'u', 'Ũ' => 'U', 'ų' => 'u', 'Ų' => 'U', 'ū' => 'u', 'Ū' => 'U', 'ư' => 'u', 'Ư' => 'U', 'ü' => 'ue', 'Ü' => 'UE', 
-			'ẃ' => 'w', 'Ẃ' => 'W', 'ẁ' => 'w', 'Ẁ' => 'W', 'ŵ' => 'w', 'Ŵ' => 'W', 'ẅ' => 'w', 'Ẅ' => 'W', 
-			'ý' => 'y', 'Ý' => 'Y', 'ỳ' => 'y', 'Ỳ' => 'Y', 'ŷ' => 'y', 'Ŷ' => 'Y', 'ÿ' => 'y', 'Ÿ' => 'Y', 
-			'ź' => 'z', 'Ź' => 'Z', 'ž' => 'z', 'Ž' => 'Z', 'ż' => 'z', 'Ż' => 'Z', 
-			'þ' => 'th', 'Þ' => 'Th', 'µ' => 'u', 
-			'а' => 'a', 'А' => 'a', 'б' => 'b', 
-			'Б' => 'b', 'в' => 'v', 'В' => 'v', 
-			'г' => 'g', 'Г' => 'g', 'д' => 'd', 
-			'Д' => 'd', 'е' => 'e', 'Е' => 'e', 
-			'ё' => 'e', 'Ё' => 'e', 'ж' => 'zh', 
-			'Ж' => 'zh', 'з' => 'z', 'З' => 'z', 
-			'и' => 'i', 'И' => 'i', 'й' => 'j', 
-			'Й' => 'j', 'к' => 'k', 'К' => 'k', 
-			'л' => 'l', 'Л' => 'l', 'м' => 'm', 
-			'М' => 'm', 'н' => 'n', 'Н' => 'n', 
-			'о' => 'o', 'О' => 'o', 'п' => 'p', 
-			'П' => 'p', 'р' => 'r', 'Р' => 'r', 
-			'с' => 's', 'С' => 's', 'т' => 't', 
-			'Т' => 't', 'у' => 'u', 'У' => 'u', 
-			'ф' => 'f', 'Ф' => 'f', 'х' => 'h', 
-			'Х' => 'h', 'ц' => 'c', 'Ц' => 'c', 
-			'ч' => 'ch', 'Ч' => 'ch', 'ш' => 'sh', 
-			'Ш' => 'sh', 'щ' => 'sch', 'Щ' => 'sch', 
-			'ъ' => '', 'Ъ' => '', 'ы' => 'y', 
-			'Ы' => 'y', 'ь' => '', 'Ь' => '', 
-			'э' => 'e', 'Э' => 'e', 'ю' => 'ju', 
+			'á' => 'a', 'Á' => 'A', 'à' => 'a', 'À' => 'A', 'ă' => 'a', 'Ă' => 'A', 'â' => 'a', 'Â' => 'A', 'å' => 'a', 'Å' => 'A', 'ã' => 'a', 'Ã' => 'A', 'ą' => 'a', 'Ą' => 'A', 'ā' => 'a', 'Ā' => 'A', 'ä' => 'ae', 'Ä' => 'AE', 'æ' => 'ae', 'Æ' => 'AE',
+			'ḃ' => 'b', 'Ḃ' => 'B',
+			'ć' => 'c', 'Ć' => 'C', 'ĉ' => 'c', 'Ĉ' => 'C', 'č' => 'c', 'Č' => 'C', 'ċ' => 'c', 'Ċ' => 'C', 'ç' => 'c', 'Ç' => 'C',
+			'ď' => 'd', 'Ď' => 'D', 'ḋ' => 'd', 'Ḋ' => 'D', 'đ' => 'd', 'Đ' => 'D', 'ð' => 'dh', 'Ð' => 'Dh',
+			'é' => 'e', 'É' => 'E', 'è' => 'e', 'È' => 'E', 'ĕ' => 'e', 'Ĕ' => 'E', 'ê' => 'e', 'Ê' => 'E', 'ě' => 'e', 'Ě' => 'E', 'ë' => 'e', 'Ë' => 'E', 'ė' => 'e', 'Ė' => 'E', 'ę' => 'e', 'Ę' => 'E', 'ē' => 'e', 'Ē' => 'E',
+			'ḟ' => 'f', 'Ḟ' => 'F', 'ƒ' => 'f', 'Ƒ' => 'F',
+			'ğ' => 'g', 'Ğ' => 'G', 'ĝ' => 'g', 'Ĝ' => 'G', 'ġ' => 'g', 'Ġ' => 'G', 'ģ' => 'g', 'Ģ' => 'G',
+			'ĥ' => 'h', 'Ĥ' => 'H', 'ħ' => 'h', 'Ħ' => 'H',
+			'í' => 'i', 'Í' => 'I', 'ì' => 'i', 'Ì' => 'I', 'î' => 'i', 'Î' => 'I', 'ï' => 'i', 'Ï' => 'I', 'ĩ' => 'i', 'Ĩ' => 'I', 'į' => 'i', 'Į' => 'I', 'ī' => 'i', 'Ī' => 'I',
+			'ĵ' => 'j', 'Ĵ' => 'J',
+			'ķ' => 'k', 'Ķ' => 'K',
+			'ĺ' => 'l', 'Ĺ' => 'L', 'ľ' => 'l', 'Ľ' => 'L', 'ļ' => 'l', 'Ļ' => 'L', 'ł' => 'l', 'Ł' => 'L',
+			'ṁ' => 'm', 'Ṁ' => 'M',
+			'ń' => 'n', 'Ń' => 'N', 'ň' => 'n', 'Ň' => 'N', 'ñ' => 'n', 'Ñ' => 'N', 'ņ' => 'n', 'Ņ' => 'N',
+			'ó' => 'o', 'Ó' => 'O', 'ò' => 'o', 'Ò' => 'O', 'ô' => 'o', 'Ô' => 'O', 'ő' => 'o', 'Ő' => 'O', 'õ' => 'o', 'Õ' => 'O', 'ø' => 'oe', 'Ø' => 'OE', 'ō' => 'o', 'Ō' => 'O', 'ơ' => 'o', 'Ơ' => 'O', 'ö' => 'oe', 'Ö' => 'OE',
+			'ṗ' => 'p', 'Ṗ' => 'P',
+			'ŕ' => 'r', 'Ŕ' => 'R', 'ř' => 'r', 'Ř' => 'R', 'ŗ' => 'r', 'Ŗ' => 'R',
+			'ś' => 's', 'Ś' => 'S', 'ŝ' => 's', 'Ŝ' => 'S', 'š' => 's', 'Š' => 'S', 'ṡ' => 's', 'Ṡ' => 'S', 'ş' => 's', 'Ş' => 'S', 'ș' => 's', 'Ș' => 'S', 'ß' => 'SS',
+			'ť' => 't', 'Ť' => 'T', 'ṫ' => 't', 'Ṫ' => 'T', 'ţ' => 't', 'Ţ' => 'T', 'ț' => 't', 'Ț' => 'T', 'ŧ' => 't', 'Ŧ' => 'T',
+			'ú' => 'u', 'Ú' => 'U', 'ù' => 'u', 'Ù' => 'U', 'ŭ' => 'u', 'Ŭ' => 'U', 'û' => 'u', 'Û' => 'U', 'ů' => 'u', 'Ů' => 'U', 'ű' => 'u', 'Ű' => 'U', 'ũ' => 'u', 'Ũ' => 'U', 'ų' => 'u', 'Ų' => 'U', 'ū' => 'u', 'Ū' => 'U', 'ư' => 'u', 'Ư' => 'U', 'ü' => 'ue', 'Ü' => 'UE',
+			'ẃ' => 'w', 'Ẃ' => 'W', 'ẁ' => 'w', 'Ẁ' => 'W', 'ŵ' => 'w', 'Ŵ' => 'W', 'ẅ' => 'w', 'Ẅ' => 'W',
+			'ý' => 'y', 'Ý' => 'Y', 'ỳ' => 'y', 'Ỳ' => 'Y', 'ŷ' => 'y', 'Ŷ' => 'Y', 'ÿ' => 'y', 'Ÿ' => 'Y',
+			'ź' => 'z', 'Ź' => 'Z', 'ž' => 'z', 'Ž' => 'Z', 'ż' => 'z', 'Ż' => 'Z',
+			'þ' => 'th', 'Þ' => 'Th', 'µ' => 'u',
+			'а' => 'a', 'А' => 'a', 'б' => 'b',
+			'Б' => 'b', 'в' => 'v', 'В' => 'v',
+			'г' => 'g', 'Г' => 'g', 'д' => 'd',
+			'Д' => 'd', 'е' => 'e', 'Е' => 'e',
+			'ё' => 'e', 'Ё' => 'e', 'ж' => 'zh',
+			'Ж' => 'zh', 'з' => 'z', 'З' => 'z',
+			'и' => 'i', 'И' => 'i', 'й' => 'j',
+			'Й' => 'j', 'к' => 'k', 'К' => 'k',
+			'л' => 'l', 'Л' => 'l', 'м' => 'm',
+			'М' => 'm', 'н' => 'n', 'Н' => 'n',
+			'о' => 'o', 'О' => 'o', 'п' => 'p',
+			'П' => 'p', 'р' => 'r', 'Р' => 'r',
+			'с' => 's', 'С' => 's', 'т' => 't',
+			'Т' => 't', 'у' => 'u', 'У' => 'u',
+			'ф' => 'f', 'Ф' => 'f', 'х' => 'h',
+			'Х' => 'h', 'ц' => 'c', 'Ц' => 'c',
+			'ч' => 'ch', 'Ч' => 'ch', 'ш' => 'sh',
+			'Ш' => 'sh', 'щ' => 'sch', 'Щ' => 'sch',
+			'ъ' => '', 'Ъ' => '', 'ы' => 'y',
+			'Ы' => 'y', 'ь' => '', 'Ь' => '',
+			'э' => 'e', 'Э' => 'e', 'ю' => 'ju',
 			'Ю' => 'ju', 'я' => 'ja', 'Я' => 'ja'
 		);
 		$tag = str_replace(array_keys($transliterationTable), array_values($transliterationTable), $tag);
@@ -347,7 +386,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Build a query from filters
-	 * 
+	 *
 	 * @param      array $filters Filters to determien hwo to build query
 	 * @return     string SQL
 	 */
@@ -359,7 +398,7 @@ class TagsTableTag extends JTable
 					INNER JOIN $this->_tbl As t ON t.id=tj.tagid
 					WHERE t.admin=0 GROUP BY tj.tagid ORDER BY tj.taggedon DESC";
 
-			if (isset($filters['limit']) && $filters['limit'] != 0  && $filters['limit'] != 'all') 
+			if (isset($filters['limit']) && $filters['limit'] != 0  && $filters['limit'] != 'all')
 			{
 				if (!isset($filters['start']))
 				{
@@ -381,38 +420,38 @@ class TagsTableTag extends JTable
 			return $query;
 		}
 
-		if (isset($filters['count']) && $filters['count']) 
+		if (isset($filters['count']) && $filters['count'])
 		{
 			$query = "SELECT count(DISTINCT t.id)";
-		} 
-		else 
+		}
+		else
 		{
-			$query = "SELECT DISTINCT t.id, t.tag, t.raw_tag, t.admin, 
-						(SELECT COUNT(*) FROM #__tags_object AS tt WHERE tt.tagid=t.id) AS total, 
+			$query = "SELECT DISTINCT t.id, t.tag, t.raw_tag, t.admin, t.created,
+						(SELECT COUNT(*) FROM #__tags_object AS tt WHERE tt.tagid=t.id) AS total,
 						(SELECT COUNT(*) FROM #__tags_substitute AS s WHERE s.tag_id=t.id) AS substitutes";
 		}
 		$tj = new TagsTableObject($this->_db);
 
 		$query .= " FROM $this->_tbl AS t";
-		if (isset($filters['by']) && $filters['by'] == 'user') 
+		if (isset($filters['by']) && $filters['by'] == 'user')
 		{
 			$query .= " JOIN " . $tj->getTableName() . " AS tj ON t.id=tj.tagid "; //AND t.raw_tag NOT LIKE 'tool:%' AND t.raw_tag NOT LIKE 'resource:%'";
 		}
-		else if (isset($filters['scope']) || isset($filters['scope_id'])) 
+		else if (isset($filters['scope']) || isset($filters['scope_id']))
 		{
 			$query .= " JOIN " . $tj->getTableName() . " AS tj ON t.`id`=tj.`tagid`";
 		}
 
 		$where = array();
 
-		if (isset($filters['search']) && $filters['search'] != '') 
+		if (isset($filters['search']) && $filters['search'] != '')
 		{
 			$query .= " LEFT JOIN #__tags_substitute AS sb ON sb.tag_id=t.id";
 			// Used to also query using unfiltered search text agains the rawtag and the tag.
 			// Figured this was safer
-			$where[] = "(LOWER(t.`raw_tag`) LIKE '" . $this->_db->getEscaped($filters['search']) . "%' OR LOWER(sb.`raw_tag`) LIKE '" . $this->_db->getEscaped($filters['search']) . "%')";
-		} 
-		if (isset($filters['by'])) 
+			$where[] = "(LOWER(t.`raw_tag`) LIKE " . $this->_db->quote($filters['search'] . '%') . " OR LOWER(sb.`raw_tag`) LIKE " . $this->_db->quote($filters['search'] . '%') . ")";
+		}
+		if (isset($filters['by']))
 		{
 			switch ($filters['by'])
 			{
@@ -422,53 +461,61 @@ class TagsTableTag extends JTable
 				default:  break;
 			}
 		}
-		if (isset($filters['tagger_id']) && $filters['tagger_id']) 
+		if (isset($filters['tagger_id']) && $filters['tagger_id'])
 		{
 			$where[] = "tj.`taggerid`=" . $this->_db->Quote((int) $filters['tagger_id']);
 		}
-		if (isset($filters['scope']) && $filters['scope']) 
+		if (isset($filters['scope']) && $filters['scope'])
 		{
 			$where[] = "tj.`tbl`=" . $this->_db->Quote((string) $filters['scope']);
 		}
-		if (isset($filters['scope_id']) && $filters['scope_id']) 
+		if (isset($filters['scope_id']) && $filters['scope_id'])
 		{
 			$where[] = "tj.`objectid`=" . $this->_db->Quote((int) $filters['scope_id']);
 		}
-		if (isset($filters['admin']) && $filters['admin'] !== null) 
+		if (isset($filters['admin']) && $filters['admin'] !== null)
 		{
 			$where[] = "t.`admin`=" . $this->_db->Quote((int) $filters['admin']);
 		}
+		if (isset($filters['created_by']) && $filters['created_by'] > 0)
+		{
+			$where[] = "t.`created_by`=" . $this->_db->Quote((int) $filters['created_by']);
+		}
+		if (isset($filters['modified_by']) && $filters['modified_by'] > 0)
+		{
+			$where[] = "t.`modified_by`=" . $this->_db->Quote((int) $filters['modified_by']);
+		}
 
 		if (count($where) > 0)
 		{
 			$query .= " WHERE " . implode(" AND ", $where);
 		}
 
-		if (isset($filters['sortby']) && $filters['sortby'] != '') 
+		if (isset($filters['sortby']) && $filters['sortby'] != '')
 		{
-			if ($filters['sortby'] == 'total') 
+			if ($filters['sortby'] == 'total')
 			{
 				$query .= " ORDER BY " . $filters['sortby'] . " DESC";
-			} 
-			else 
+			}
+			else
 			{
 				$query .= " ORDER BY t." . $filters['sortby'];
 			}
-		} 
-		else 
+		}
+		else
 		{
-			if (isset($filters['sort']) && $filters['sort'] != '' && (!isset($filters['count']) || !$filters['count'])) 
+			if (isset($filters['sort']) && $filters['sort'] != '' && (!isset($filters['count']) || !$filters['count']))
 			{
 				$filters['sort_Dir'] = (isset($filters['sort_Dir']) && $filters['sort_Dir']) ? $filters['sort_Dir'] : "ASC";
 				$query .= " ORDER BY " . $filters['sort'] . " " . $filters['sort_Dir'];
 			}
-			else 
+			else
 			{
 				$query .= " ORDER BY t.raw_tag ASC";
 			}
 		}
 
-		if (isset($filters['limit']) && $filters['limit'] != 0  && $filters['limit'] != 'all') 
+		if (isset($filters['limit']) && $filters['limit'] != 0  && $filters['limit'] != 'all')
 		{
 			if (!isset($filters['start']))
 			{
@@ -482,7 +529,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get a record count
-	 * 
+	 *
 	 * @param      array $filters Filters to determien hwo to build query
 	 * @return     integer
 	 */
@@ -498,7 +545,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get records
-	 * 
+	 *
 	 * @param      array $filters Filters to determien hwo to build query
 	 * @return     array
 	 */
@@ -510,7 +557,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get tags for an object
-	 * 
+	 *
 	 * @param      string  $tbl      Object type
 	 * @param      integer $state    Object state
 	 * @param      integer $objectid Object ID
@@ -521,9 +568,9 @@ class TagsTableTag extends JTable
 		$tj = new TagsTableObject($this->_db);
 
 		$sql  = "SELECT t.tag, t.raw_tag, t.admin, COUNT(*) as count
-				FROM $this->_tbl AS t 
+				FROM $this->_tbl AS t
 				INNER JOIN " . $tj->getTableName() . " AS rt ON (rt.tagid = t.id) AND rt.tbl=" . $this->_db->Quote($tbl) . " ";
-		if (isset($objectid) && $objectid) 
+		if (isset($objectid) && $objectid)
 		{
 			$sql .= "WHERE rt.objectid=" . $this->_db->Quote($objectid) . " ";
 		}
@@ -548,25 +595,25 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Search for tags containing the search string
-	 * 
+	 *
 	 * @param      array $filters Params for building the query
 	 * @return     array
 	 */
 	public function getAutocomplete($filters=array())
 	{
-		$query = "SELECT DISTINCT t.id, t.tag, t.raw_tag 
-					FROM $this->_tbl AS t 
+		$query = "SELECT DISTINCT t.id, t.tag, t.raw_tag
+					FROM $this->_tbl AS t
 					LEFT JOIN #__tags_substitute AS s ON s.tag_id=t.id
 					WHERE";
-		if (isset($filters['admin']) && $filters['admin']) 
+		if (isset($filters['admin']) && $filters['admin'])
 		{
 			$query .= "";
-		} 
-		else 
+		}
+		else
 		{
 			$query .= " admin=0 AND";
 		}
-		$query .= " (LOWER(t.raw_tag) LIKE '" . $this->_db->getEscaped($filters['search']) . "%' OR LOWER(s.raw_tag) LIKE '" . $this->_db->getEscaped($filters['search']) . "%') 
+		$query .= " (LOWER(t.raw_tag) LIKE " . $this->_db->quote($filters['search'] . '%') . " OR LOWER(s.raw_tag) LIKE " . $this->_db->quote($filters['search'] . '%') . ")
 					ORDER BY t.raw_tag ASC";
 
 		$this->_db->setQuery($query);
@@ -575,24 +622,24 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get a list of all tags
-	 * 
+	 *
 	 * @param      boolean $authorized Administrator?
 	 * @return     array
 	 */
 	public function getAllTags($authorized=false)
 	{
-		if (!$authorized) 
+		if (!$authorized)
 		{
 			$filter = "WHERE admin=0 ";
-		} 
-		else 
+		}
+		else
 		{
 			$filter = "";
 		}
 
-		$query = "SELECT id, tag, raw_tag, admin, COUNT(*) as tcount 
-				FROM $this->_tbl $filter 
-				GROUP BY raw_tag 
+		$query = "SELECT id, tag, raw_tag, admin, COUNT(*) as tcount
+				FROM $this->_tbl $filter
+				GROUP BY raw_tag
 				ORDER BY raw_tag ASC";
 
 		$this->_db->setQuery($query);
@@ -601,7 +648,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get the top used tags
-	 * 
+	 *
 	 * @param      integer $limit           Number of tags to get
 	 * @param      string  $tbl             Object type
 	 * @param      string  $order           Sort results by
@@ -615,18 +662,18 @@ class TagsTableTag extends JTable
 		$sql  = "SELECT t.tag, t.raw_tag, t.admin, tj.tagid, tj.objectid, COUNT(tj.tagid) AS tcount ";
 		$sql .= "FROM $this->_tbl AS t  ";
 		$sql .= "JOIN " . $tj->getTableName() . " AS tj ON t.id=tj.tagid ";
-		if ($exclude_private) 
+		if ($exclude_private)
 		{
 			$sql .= " LEFT JOIN #__resources AS R ON R.id=tj.objectid AND tj.tbl='resources' ";
 			$sql .= " LEFT JOIN #__wiki_page AS P ON P.id=tj.objectid AND tj.tbl='wiki' ";
 			$sql .= " LEFT JOIN #__xprofiles AS XP ON XP.uidNumber=tj.objectid AND tj.tbl='xprofiles' ";
 		}
 		$sql .= "WHERE t.id=tj.tagid AND t.admin=0 ";
-		if ($tbl) 
+		if ($tbl)
 		{
 			$sql .= "AND tj.tbl=" . $this->_db->Quote($tbl) . " ";
-		} 
-		else 
+		}
+		else
 		{
 			$sql .= ($exclude_private) ? " AND ((tj.tbl='resources' AND R.access!=4 AND R.published=1) OR (tj.tbl='wiki' AND P.access=0 AND P.state<2) OR (tj.tbl='xprofiles' AND XP.public=0) OR tj.tbl NOT IN ('xprofiles','wiki','resources','wishlist','support')) " : "";
 		}
@@ -640,7 +687,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get recently used tags
-	 * 
+	 *
 	 * @param      integer $limit Number of tags to find
 	 * @param      string  $order Sort results by
 	 * @return     array
@@ -652,19 +699,19 @@ class TagsTableTag extends JTable
 		$sql  = "SELECT t.tag, t.raw_tag, t.admin, tj.taggedon, COUNT(tj.tagid) AS tcount ";
 		$sql .= "FROM $this->_tbl AS t  ";
 		$sql .= "JOIN " . $tj->getTableName() . " AS tj ON t.id=tj.tagid "; //AND t.raw_tag NOT LIKE 'tool:%' AND t.raw_tag NOT LIKE 'resource:%' ";
-		if ($exclude_private) 
+		if ($exclude_private)
 		{
 			$sql.= "LEFT JOIN #__resources AS R ON R.id=tj.objectid AND tj.tbl='resources' ";
 			$sql.= "LEFT JOIN #__wiki_page AS P ON P.id=tj.objectid AND tj.tbl='wiki' ";
 			$sql.= "LEFT JOIN #__xprofiles AS XP ON XP.uidNumber=tj.objectid AND tj.tbl='xprofiles' ";
 		}
 		$sql.= "WHERE t.id=tj.tagid AND t.admin=0 ";
-		if ($exclude_private) 
+		if ($exclude_private)
 		{
 			$sql .= "AND (
-				(tj.tbl='resources' AND R.access!=4) OR 
-				(tj.tbl='wiki' AND P.access=0) OR 
-				(tj.tbl='xprofiles' AND XP.public=0) OR 
+				(tj.tbl='resources' AND R.access!=4) OR
+				(tj.tbl='wiki' AND P.access=0) OR
+				(tj.tbl='xprofiles' AND XP.public=0) OR
 				(tj.tbl NOT IN ('xprofiles', 'wiki', 'resources', 'wishlist', 'support'))
 				) ";
 		}
@@ -678,25 +725,25 @@ class TagsTableTag extends JTable
 	/**
 	 * Get tags related to another tag
 	 * Relation is based off of number of uses on same objects
-	 * 
+	 *
 	 * @param      integer $id    ID of tag to find relations to
 	 * @param      integer $limit Number of tags to find
 	 * @return     mixed Array of tags if results found, null if not
 	 */
 	public function getRelatedTags($id=null, $limit=25)
 	{
-		if (!$id) 
+		if (!$id)
 		{
 			$id = $this->id;
 		}
-		if (!$id) 
+		if (!$id)
 		{
 			return null;
 		}
 
 		$this->_db->setQuery("SELECT objectid, tbl FROM #__tags_object WHERE tagid=" . $this->_db->Quote($id));
 		$objs = $this->_db->loadObjectList();
-		if ($objs) 
+		if ($objs)
 		{
 			$sql = "SELECT t.* FROM $this->_tbl AS t, #__tags_object AS tg WHERE t.id=tg.tagid AND tg.tagid != " . $this->_db->Quote($id) . " AND t.admin=0 AND (";
 			$s = array();
@@ -709,8 +756,8 @@ class TagsTableTag extends JTable
 
 			$this->_db->setQuery($sql);
 			return $this->_db->loadObjectList();
-		} 
-		else 
+		}
+		else
 		{
 			return null;
 		}
@@ -718,7 +765,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get all the substitutions for this tag
-	 * 
+	 *
 	 * @param      integer $tag_id   Tag ID
 	 * @param      boolean $asString Return results as string?
 	 * @param      integer $offset   Record offset
@@ -727,7 +774,7 @@ class TagsTableTag extends JTable
 	 */
 	public function getSubstitutions($tag_id=null, $asString=false, $offset=0, $limit=0)
 	{
-		if (!$tag_id) 
+		if (!$tag_id)
 		{
 			$tag_id = $this->id;
 		}
@@ -744,7 +791,7 @@ class TagsTableTag extends JTable
 
 	/**
 	 * Get all the substitutions for this tag
-	 * 
+	 *
 	 * @param      integer $tag_id   Tag ID
 	 * @param      boolean $asString Return results as string?
 	 * @param      integer $offset   Record offset
@@ -753,11 +800,11 @@ class TagsTableTag extends JTable
 	 */
 	public function saveSubstitutions($tag_string='', $tag_id=null)
 	{
-		if (!$tag_id) 
+		if (!$tag_id)
 		{
 			$tag_id = $this->id;
 		}
-		if (!$tag_id) 
+		if (!$tag_id)
 		{
 			$this->setError(JText::_('Missing argument.'));
 			return false;
@@ -801,7 +848,7 @@ class TagsTableTag extends JTable
 		$remove = array();
 		foreach ($subs as $key => $sub)
 		{
-			if (!in_array($key, $tags)) 
+			if (!in_array($key, $tags))
 			{
 				$remove[] = $key;
 			}
@@ -809,7 +856,7 @@ class TagsTableTag extends JTable
 		$ts = new TagsTableSubstitute($this->_db);
 		if (count($remove) > 0)
 		{
-			if (!$ts->removeForTag($tag_id, $remove)) 
+			if (!$ts->removeForTag($tag_id, $remove))
 			{
 				$this->setError($this->_db->getErrorMsg());
 				return false;
@@ -829,7 +876,7 @@ class TagsTableTag extends JTable
 			// Move associations on tag and delete tag
 			foreach ($ids as $id)
 			{
-				if ($tag_id != $id->id) 
+				if ($tag_id != $id->id)
 				{
 					// Get all the associations to this tag
 					// Loop through the associations and link them to a different tag
