@@ -3,7 +3,7 @@
  * @package     Joomla.Platform
  * @subpackage  Database
  *
- * @copyright   Copyright (C) 2005 - 2013 Open Source Matters, Inc. All rights reserved.
+ * @copyright   Copyright (C) 2005 - 2014 Open Source Matters, Inc. All rights reserved.
  * @license     GNU General Public License version 2 or later; see LICENSE
  */
 
@@ -54,7 +54,7 @@ class JDatabaseImporterMySQLi extends JDatabaseImporterMySQL
 	 *
 	 * @since   11.1
 	 */
-	public function setDbo(JDatabaseMySQLi $db)
+	public function setDbo($db)
 	{
 		$this->db = $db;
 
