@@ -177,8 +177,6 @@ HUB.Members.Profile = {
 			data: form.serialize(),
 			success: function(data, status, xhr)
 			{
-				console.log(data);
-				//console.log(data); // Dump the raw data to see what's being returned
 				//parse the returned json data
 				var returned = jQuery.parseJSON(data);
 				
@@ -191,8 +189,13 @@ HUB.Members.Profile = {
 				{
 					switch( profile_field )
 					{
-						case 'email': 	HUB.Members.Profile.editRedirect(window.location.href);		break;
-						default: 		HUB.Members.Profile.editReloadSections();
+						case 'email':
+						case 'usageAgreement':
+							HUB.Members.Profile.editRedirect(window.location.href);
+						break;
+						
+						default:
+							HUB.Members.Profile.editReloadSections();
 					}
 				}
 				else if(returned.loggedout)
@@ -760,7 +763,7 @@ HUB.Members.Profile = {
 				//do we have a country
 				if (jQuery.inArray('country', result[i].types) > -1)
 				{
-					address_parts['country'] = result[i].long_name.toUpperCase();
+					address_parts['country'] = result[i].long_name;
 				}
 			}
 			
